InMemoryNativeSharedPreferencesStore class

Stores data in memory.

Data does not persist across application restarts. This is useful in unit-tests.

Inheritance

Constructors

InMemoryNativeSharedPreferencesStore.empty()
Instantiates an empty in-memory preferences store.
InMemoryNativeSharedPreferencesStore.withData(Map<String, Object> data)
Instantiates an in-memory preferences store containing a copy of data.

Properties

hashCode → int
The hash code for this object.
no setterinherited
isMock → bool
Only mock implementations should set this to true.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

clear() → Future<bool>
Removes all keys and values in the store.
override
getAll() → Future<Map<String, Object>>
Returns all key/value pairs persisted in this store.
override
getAllFromDictionary(List<String> keys) → Future<Map<String, Object>>
Returns all key/value pairs persisted in this store.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
remove(String key) → Future<bool>
Removes the value associated with the key.
override
setValue(String valueType, String key, Object value) → Future<bool>
Stores the value associated with the key.
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited